netapp_ontap.models.security_key_manager_restore_keys API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_key_manager_restore_keys`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityKeyManagerRestoreKeysSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityKeyManagerRestoreKeys object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `key_id: str GET POST PATCH`

    Key identifier.

    Example: 000000000000000002000000000001003aa8ce6a4fea3e466620134bea9510a10000000000000000

  `key_server: str GET POST PATCH`

    External key server for key management.

    Example: keyserver1.com:5698

  `key_tag: str GET POST PATCH`

    Additional information associated with the key.

    Example: Authentication-Key-01

  `links: SelfLink GET`

    The links field of the security_key_manager_restore_keys.

  `node: NodeUuid GET POST PATCH`

    The node field of the security_key_manager_restore_keys.